=======
Credits
=======

NiaPy would not be possible without the following people.


Contributors
------------

* Grega Vrbančič (`@GregaVrbancic`_)
* firefly-cpp (`@firefly-cpp`_)
* Lucija Brezočnik (`@lucijabrezocnik`_)
* mlaky88 (`@mlaky88`_)
* rhododendrom (`@rhododendrom`_)
* Klemen (`@kb2623`_)
* Jan Popič (`@flyzoor`_)
* Luka Pečnik (`@lukapecnik`_)
* Jan Banko (`@bankojan`_)
* RokPot (`@RokPot`_)
* mihaelmika (`@mihael-mika`_)

.. _`@GregaVrbancic`: https://github.com/GregaVrbancic
.. _`@firefly-cpp`: https://github.com/firefly-cpp
.. _`@lucijabrezocnik`: https://github.com/lucijabrezocnik
.. _`@mlaky88`: https://github.com/mlaky88
.. _`@rhododendrom`: https://github.com/rhododendrom
.. _`@kb2623`: https://github.com/kb2623
.. _`@flyzoor`: https://github.com/flyzoor
.. _`@lukapecnik`: https://github.com/lukapecnik
.. _`@bankojan`: https://github.com/bankojan
.. _`@RokPot`: https://github.com/RokPot
.. _`@mihael-mika`: https://github.com/mihael-mika
